(function(){
/**
 * Contents Transfer Tool core module.
 *
 * @module ctt
 * @class ctt
 */
dixim.namespace('dixim.ctt');

/**
 * @property jQuery
 * @type {jQuery}
 * @static
 */
dixim.ctt.jQuery = jQuery;

/**
 * Initializes the ctt module.
 *
 * The initialization process is async,
 * so this method accepts a callback function
 * that is called when the initialization finished.
 *
 * @method init
 * @static
 * @param {Function} [fn] a callback function.
 * @param {Object} [context]
 */
dixim.ctt.init = function(fn, context) {
    var c = arguments[1] || this;
    var f = !!fn ? dixim.proxy(fn, c) : function(){};

    f.call(context);
};

}());

/**
 * @module ctt
 * @submodule configs
 */
(function() {
var cfgs;
var hostname = ['http://', location.hostname].join('');
var ports = ['55247', '47829', '41937', '54821', '55958'];
var DEFAULTS = {
    api: [hostname, ':', ports[0], '/dms/transfer_tool/api'].join(''),
    apiArs: [hostname, ':', ports[0], '/dms/ars'].join(''),
    apiAts: [hostname, ':', ports[0], '/dms/ats'].join(''),
    apiAds: [hostname, ':', ports[0], '/dms/ads'].join(''),
    apiXsrs: [hostname, ':', ports[0], '/dms/xsrs'].join(''),
    apiDtcpPlus: [hostname, ':', ports[0], '/dms/dtcp_plus'].join(''),
    apiDas: [hostname, ':', ports[0], '/dms/das'].join(''),
    apiAcs: [hostname, ':', ports[0], '/dms/acs'].join(''),
    apiCds: [hostname, ':', ports[0], '/dms/cds'].join(''),
    apiDcs: [hostname, ':', ports[0], '/dms/dcs'].join(''),
    apiMtms: [hostname, ':', ports[0], '/dms/mtms'].join(''),
    apiFs: [hostname, ':', ports[0], '/dms/fs'].join(''),
    apiEmds: [hostname, ':', ports[0], '/dms/emds'].join(''),
    apiDeviceManager: [hostname, ':', ports[1], '/dm/device_manager'].join(''),
    apiDasVdms: [hostname, ':', ports[3], '/dms/das'].join(''),
    apiAcsVdms: [hostname, ':', ports[3], '/dms/acs'].join(''),
    apiCcsVdms: [hostname, ':', ports[3], '/dms/ccs'].join(''),
    apiPdsVdms: [hostname, ':', ports[3], '/dms/pds'].join(''),
    apiDeviceManagerVdms: [hostname, ':', ports[2], '/dm/device_manager'].join(''),
    apiDragdPlus: [hostname, ':', ports[4], '/drgd/dragd_plus'].join(''),
    resourceBundleCommonPath: 'lang/common/',
    resourceBundlePath: 'lang/common/',
    imagePath: 'images/common',
    cssPath: 'css/common',
};

/**
 * @class Configs
 */
dixim.ctt.Configs = {
    /**
    * @method get
    * @param {String} key
    * @return {Object}
    */
    get: function(key) {
        return DEFAULTS[key];
    },

    /**
    * @method set
    * @param {String} key
    * @param {Object} value
    */
    set: function(key, value) {
        DEFAULTS[key] = value;
    }
};

}());

/**
 * @module ctt
 * @submodule resource-bundle
 */
(function() {
var $ = dixim.ctt.jQuery;
var Configs = dixim.ctt.Configs;
var i18n = null;
var slice = Array.prototype.slice;

/**
 * Gets a resource for the key specified.
 * @class ResourceBundle
 *
 */
dixim.ctt.ResourceBundle = {
    /**
     * @method get
     * @static
     * @param {String} [key]
     * @param {Object} [args*]
     */
    get: function() {
        var path = '';
        var text = '';
        var query = {
            name:'strings',
            language: 'ja',
            mode: 'map',
        };

        if (!!!i18n) {
            path = Configs.get('resourceBundlePath');
            if (! path.match(new RegExp('/$'))) {
                path += '/';
            }
            query.path = path;
            $.i18n.properties(query);
            i18n = $.i18n;
        }
        text = i18n.prop.apply(i18n, slice.call(arguments, 0));

        if (text.match(/^\[[a-z|A-Z|\d|_]*\]$/) !== null) {
            path = Configs.get('resourceBundleCommonPath');
            if (! path.match(new RegExp('/$'))) {
                path += '/';
            }
            query.path = path;
            $.i18n.properties(query);
            i18n = $.i18n;
        }
        text = i18n.prop.apply(i18n, slice.call(arguments, 0));
        return text;
    },
    /**
     * @method reset
     * @static
     */
    reset: function() {
        i18n = null;
    },
};

}());
