/**
 * @module dixim
 * @submodule autoDownload
 */
dixim.namespace('dixim.autoDownload');

/**
 * @module autoDownload
 * @submodule auto-download-setting-dialog-controller
 */

(function() {
var AutoDownloadSettingDialogController;
var prototype;
var superConstructor;
var AutoDownloadSettingDialogView = dixim.autoDownload.AutoDownloadSettingDialogView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientAutoDownload = dixim.common.ApiClientAutoDownload;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;

/**
 * @class AutoDownloadSettingDialogController
 * @constructor
 * @param {Object} configs
 */
AutoDownloadSettingDialogController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(AutoDownloadSettingDialogController, EventTarget);
dixim.autoDownload.AutoDownloadSettingDialogController = AutoDownloadSettingDialogController;
prototype = AutoDownloadSettingDialogController.prototype;
superConstructor = AutoDownloadSettingDialogController.superConstructor;

var SETTING = 'setting';
var UPDATE = 'update';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'auto-download-setting-dialog'].join('');

    this._model = new ApiClientAutoDownload();
    this._model.addEventListener('fetchDownloadMoveSetting', this._successFetchDownloadMoveSetting, this);
    this._model.addEventListener('fetchDownloadMoveSettingError', this._errorFetchDownloadMoveSetting, this);
    this._model.addEventListener('fetchSpace', this._successFetchSpace, this);
    this._model.addEventListener('fetchSpaceError', this._errorFetchSpace, this);
    this._model.addEventListener('setDownloadMoveSetting', this._successSetDownloadMoveSetting, this);
    this._model.addEventListener('setDownloadMoveSettingError', this._errorSetDownloadMoveSetting, this);
    this._model.addEventListener('setSpace', this._successSetSpace, this);
    this._model.addEventListener('setSpaceError', this._errorSetSpace, this);

    this._view = new AutoDownloadSettingDialogView(configs);
    this._view.addEventListener(SETTING, this._clickSetting, this);

    this._requestingCount = 0;
    this._requestingError;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();
    this._model.fetchDownloadMoveSetting();
    this._model.fetchSpace();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._successFetchDownloadMoveSetting = function(e) {
    this._view.setValue(e.args);
};

prototype._errorFetchDownloadMoveSetting = function() {
    this._errorDialog(_('auto_download_setting_move_fetch_error'));
};

prototype._successFetchSpace = function(e) {
    this._view.setValue(e.args);
};

prototype._errorFetchSpace = function() {
    this._errorDialog(_('auto_download_setting_threshold_fetch_error'));
};

prototype._clickSetting = function(e) {
    var query = {};

    if (!e.args.size.match('^[0-9]{1,4}$')) {
        this._errorDialog(_('auto_download_setting_error_description'));
        return;
    }
    this._view.startIndicator();
    this._requestingError = false;
    this._requestingCount = 2;
    query.allowMove = e.args.allowMove;
    query.size = parseInt(e.args.size, 10) * 1024 * 1024 * 1024;
    this._model.setDownloadMoveSetting(query);
    this._model.setSpace(query);
};

prototype._successSetDownloadMoveSetting = function() {
    this._requestingCount -= 1;
    if (this._requestingCount === 0) {
        this._completeSetMoveSettingAndSpace();
    }
};

prototype._errorSetDownloadMoveSetting = function() {
    this._requestingCount -= 1;
    this._requestingError = true;
    if (this._requestingCount === 0) {
        this._completeSetMoveSettingAndSpace();
    }
};

prototype._successSetSpace = function() {
    this._requestingCount -= 1;
    if (this._requestingCount === 0) {
        this._completeSetMoveSettingAndSpace();
    }
};

prototype._errorSetSpace = function() {
    this._requestingCount -= 1;
    this._requestingError = true;
    if (this._requestingCount === 0) {
        this._completeSetMoveSettingAndSpace();
    }
};

prototype._completeSetMoveSettingAndSpace = function() {
    if (this._requestingError) {
        this._errorDialog(_('auto_download_setting_error_description'));
    } else {
        this._callbackUpdate();
    }
};

prototype._callbackUpdate = function() {
    this.stop();
    this.dispatchEvent(new Event(UPDATE));
};

prototype._errorDialog = function(text) {
    var query = {};
    var dialog;

    query.id = this._id;
    query.title = _('auto_download_setting_auto_save_setting');
    query.description = text;
    query.doubleDialog = true;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
