/**
 * @module dixim
 * @submodule download
 */
dixim.namespace('dixim.download');

/**
 * @module download
 * @submodule download-wizard-confirm-dialog-view
 */

(function() {
var DownloadWizardConfirmDialogView;
var superConstructor;
var prototype;
var ModalDialogView = dixim.common.ModalDialogView;
var Formatter = dixim.ctt.util.Formatter;
var _ = dixim.ctt.ResourceBundle.get;
var Event = dixim.event.Event;
var $ = dixim.ctt.jQuery;
var escape = dixim.xml.escape;

/**
 * @class DownloadWizardConfirmDialogView
 * @constructor
 * @param {Object} configs
 */
DownloadWizardConfirmDialogView = function(configs) {
    ModalDialogView.call(this, configs);
};

dixim.inherit(DownloadWizardConfirmDialogView, ModalDialogView);
dixim.download.DownloadWizardConfirmDialogView = DownloadWizardConfirmDialogView;
prototype = DownloadWizardConfirmDialogView.prototype;
superConstructor = DownloadWizardConfirmDialogView.superConstructor;

var START = 'start';
var TEMPLATE_BODY_CONTENT = [
    '<div id="confirm-description-field" class="confirm-description dlg_main_msg">',
    '<span>', '${description}', '</span>',
    '</div>',
    '<div id="confirm-list-field" class="confirm-list-field">',
    '<div id="confirm-body" class="dlg_scroll dl_tbl">',
    '<div id="confirm-attention-field" class="confirm-attention-field color_red txt_s">',
    '<span class="confirm-attention">', '${deleteDescription}', '</span>', '<br />',
    '<span class="confirm-attention">', '${copyCountDescription}', '</span>',
    '</div>',
    '<dl id="confirmSrc">',
    '<dt class="confirm-list-description">', '${confirmSrc}','</dt>',
    '<dd class="confirm-list">', '${serverName}', '</dd>',
    '</dl>',
    '<dl id="confirmDst">',
    '<dt class="confirm-list-description">', '${confirmDst}','</dt>',
    '<dd class="confirm-list">', '${dstDirName}', '</dd>',
    '</dl>',
    '<div id="confirm-sd-first-field">',
    '<label class="select-pointer">', '<input type="checkbox" id="sd-first" />',
    '<span id="sd-first-confirm">', '${sdFirst}', '</span>',
    '</div>',
    '</div>',
    '</div>',
].join('');

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    configs.id = [configs.id, 'download-wizard-confirm-dialog-'].join('');

    this._downloadConfigs = configs.downloadConfigs;

    configs.bodyContent = TEMPLATE_BODY_CONTENT
        .replace('${description}', _('download_wizard_confirm_description', this._downloadConfigs.dataList.length))
        .replace('${deleteDescription}', _('download_wizard_confirm_attention_delete'))
        .replace('${copyCountDescription}', _('download_wizard_confirm_attention_copy_count'))
        .replace('${confirmSrc}', _('download_wizard_confirm_src'))
        .replace('${serverName}', escape(this._downloadConfigs.serverInfo.friendlyName))
        .replace('${confirmDst}', _('download_wizard_confirm_dst'))
        .replace('${dstDirName}', this._downloadConfigs.dst.title)
        .replace('${sdFirst}', _('download_wizard_confirm_sd_first'));

    configs.title = _('download_wizard_title');
    configs.doubleDialog = true;
    configs.contentHeight = configs.contentHeight || 'auto';
    configs.returnButton = dixim.proxy(this.hide, this);
    configs.buttons = [
        {text: _('dialog_start'), click: dixim.proxy(this._clickStart, this)},
    ];

    superConstructor.prototype._initialize.call(this, configs);
};

prototype._render = function() {
    var date = '';
    var startTime = this._downloadConfigs.startTime;

    if (typeof startTime !== 'undefined') {
        date = Formatter.dcDateToDate(startTime);
        date = Formatter.stringifyDate(date, 'YYYY/MM/DD hh:mm');
        $('#confirmDst').after([
            '<dl id="confirmDate">',
            '<dt id="confirm-date" class="confirm-list-description">', _('download_wizard_confirm_start_data'), '</dt>',
            '<dd id="confirm-date-name" class="confirm-list">', date, '</dd>',
            '</dl>',
        ].join(''));
    }

    $('#confirm-body').height([parseInt(this._contentHeight, 10) - parseInt($('#confirm-description-field').outerHeight(), 10), 'px'].join(''));
};

prototype._clickStart = function() {
    var info = {};

    info.isFirstSd = $('#sd-first').is(':checked');
    this.dispatchEvent(new Event(START, info));
};

}());
