/**
 * @module dixim
 * @submodule server
 */
dixim.namespace('dixim.server');

/**
 * @module server
 * @submodule friendly-name-controller
 */

(function() {
var FriendlyNameController;
var prototype;
var superConstructor;
var FriendlyNameView = dixim.server.FriendlyNameView;
var EventTarget = dixim.event.EventTarget;
var _ = dixim.ctt.ResourceBundle.get;
var ApiClientServer = dixim.common.ApiClientServer;
var ErrorModalDialogView = dixim.common.ErrorModalDialogView;
var BlockUi = dixim.common.BlockUi;

/**
 * @class FriendlyNameController
 * @constructor
 * @param {Object} configs
 */
FriendlyNameController = function(configs) {
    EventTarget.call(this);
    this._initialize(configs);
};

dixim.inherit(FriendlyNameController, EventTarget);
dixim.server.FriendlyNameController = FriendlyNameController;
prototype = FriendlyNameController.prototype;
superConstructor = FriendlyNameController.superConstructor;

var FORMAT = 'format';
var APPLY = 'apply';
var PREV = 'prev';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
    configs = configs || {};

    configs.id = configs.id || '';
    this._id = [configs.id, 'friendly-name'].join('');

    this._model = new ApiClientServer();
    this._model.addEventListener('fetchFriendlyName', this._successFetchFriendlyName, this);
    this._model.addEventListener('fetchFriendlyNameError', this._errorFetchFriendlyName, this);
    this._model.addEventListener('changeFriendlyName', this._successChangeFriendlyName, this);
    this._model.addEventListener('changeFriendlyNameError', this._errorChangeFriendlyName, this);
    this._model.addEventListener('resetFriendlyName', this._successResetFriendlyName, this);
    this._model.addEventListener('resetFriendlyNameError', this._errorResetFriendlyName, this);

    this._view = new FriendlyNameView(configs);
    this._view.addEventListener(FORMAT, this._clickFormat, this);
    this._view.addEventListener(APPLY, this._clickApply, this);
    this._view.addEventListener(PREV, this._clickPrev, this);

    this._blockUi = new BlockUi();

    this._parentContext = configs.parentContext;
};

/**
 * @method start
 */
prototype.start = function() {
    this._view.show();

    this._view.setValue(_('server_friendly_name_getting_info_process'), false);
    this._fetchFriendlyName();
};

/**
 * @method stop
 */
prototype.stop = function() {
    this._view.hide();
};

prototype._fetchFriendlyName = function() {
    this._blockUi.block();
    this._model.fetchFriendlyName();
};

prototype._successFetchFriendlyName = function(e) {
    this._view.setValue(e.args.friendlyName, false);
    this._blockUi.unblock();
};

prototype._errorFetchFriendlyName = function() {
    this._view.setValue(_('server_friendly_name_error'), true, true);
    this._blockUi.unblock();
};

prototype._successChangeFriendlyName = function(e) {
    this._blockUi.unblock();
    this._fetchFriendlyName();
};

prototype._errorChangeFriendlyName = function() {
    this._blockUi.unblock();
    this._errorDialog(_('server_friendly_name_error_change_description'));
};

prototype._successResetFriendlyName = function(e) {
    this._blockUi.unblock();
    this._fetchFriendlyName();
};

prototype._errorResetFriendlyName = function() {
    this._blockUi.unblock();
    this._errorDialog(_('server_friendly_name_error_format_description'));
};

prototype._clickFormat = function() {
    this._blockUi.block();
    this._model.resetFriendlyName();
};

prototype._clickApply = function(e) {
    var query = {};

    this._blockUi.block();

    query.friendlyName = e.args.friendlyName;
    this._model.changeFriendlyName(query);
};

prototype._clickPrev = function() {
    this.stop();
    this._parentContext.start();
};

prototype._errorDialog = function(text) {
    var query = {};
    var dialog;

    query.id = this._id;
    query.title = _('server_menu_friendly_name');
    query.description = text;
    dialog = new ErrorModalDialogView(query);
    dialog.show();
};

}());
