/**
 * @module dixim
 * @submodule dixim-timer
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;

var Timer;
var prototype;

/**
 * Class for handling timing event.
 *
 * @class Timer
 * @extends EventTarget
 * @uses Event
 * @constructor
 * @param {Object} [configs]
 * @param {Number} [configs.interval=1000] tick interval(ms).
 */
Timer = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(Timer, EventTarget);
dixim.Timer = Timer;
prototype = Timer.prototype;

/**
 * @event tick
 */
var TICK = 'tick';

/**
 * @method _initialize
 * @protected
 */
prototype._initialize = function(configs) {
  var cfg = {interval: 1000};

  cfg = dixim.extend(cfg, configs);
  this._interval = cfg.interval || 1000;
  this._intervalId = null;
};

/**
 * @method start
 */
prototype.start = function() {
  this._startTicker();
};

prototype._startTicker = function() {
  if (!!this._intervalId) return;
  this._intervalId = setInterval(dixim.proxy(this._tick, this),
                                 this._interval);
};

prototype._tick = function(e) {
  this.dispatchEvent(new Event(TICK));
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._invalidateTicker();
};

/**
 * @method invalidate
 */
prototype.invalidate = function() {
  this._invalidateTicker();
};

/**
 * @method _invalidateTicker
 */
prototype._invalidateTicker = function() {
  if (!!!this._intervalId) return;
  clearInterval(this._intervalId);
  this._intervalId = null;
};

}());
