/**
 * @module ctt
 * @submodule confirmation-wizard-page-view
 */
(function() {
var Event = dixim.event.Event;
var WizardPageView = dixim.ctt.WizardPageView;
var _ = dixim.ctt.ResourceBundle.get;
var $ = dixim.ctt.jQuery;

var ConfirmationWizardPageView;
var prototype;
var superConstructor;

/**
 * @class ConfirmationWizardPageView
 * @extends WizardPageView
 * @constructor
 * @param {Object} configs
 */
ConfirmationWizardPageView = function(configs) {
  WizardPageView.call(this, configs);
};
dixim.inherit(ConfirmationWizardPageView, WizardPageView);
dixim.ctt.ConfirmationWizardPageView = ConfirmationWizardPageView;
prototype = ConfirmationWizardPageView.prototype;
superConstructor = ConfirmationWizardPageView.superConstructor;

var TEMPLATE = ['<div class="ctt-confirmation-wizard-page-view">',
                  '<div class="ctt-confirmation-wizard-page-view-description"></div>',
                  '<table class="ctt-confirmation-wizard-page-view-collected-information">',
                    '<tr><td>${dms}</td><td class="ctt-confirmation-wizard-page-view-collected-information-dms-name"></td></tr>',
                    '<tr><td>${storage}</td><td class="ctt-confirmation-wizard-page-view-collected-information-storage-name"></td></tr>',
                    '<tr><td>${scheduled}</td><td class="ctt-confirmation-wizard-page-view-collected-information-scheduled-date"></td></tr>',
                  '</table>',
                  '<div id="ctt-confirmation-wizard-caution" class="ctt-confirmation-wizard-page-view-caution">${caution}</div>',
                  '<div id="ctt-confirmation-wizard-confirm" class="ctt-confirmation-wizard-page-view-confirm"></div>',
                  '<form class="ctt-confirmation-wizard-page-view-shutdown" style="display: none;">',
                    '<input type="checkbox" name="shutdown" />${shutdownOnceFinished}</form>',
                '</div>'].join('');

/**
 * Triggered when the view has been rendered.
 * 
 * @event render
 */
var RENDER = 'render';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  var buttons;
  var cfg = {};

  this._isDownloadMoveIn = !!configs.isDownloadMoveIn;
  if (this._isDownloadMoveIn) {
    cfg.title = _('ctt_download_wizard_title');
    cfg.bodyContent = TEMPLATE.
                      replace('${dms}', _('ctt_confirmation_wizard_page_view_information_label_dms_download')).
                      replace('${storage}', _('ctt_confirmation_wizard_page_view_information_label_storage_download')).
                      replace('${scheduled}', _('ctt_confirmation_wizard_page_view_information_label_scheduled')).
                      replace('${shutdownOnceFinished}',  _('ctt_confirmation_wizard_page_view_shutdown_once_finished')).
                      replace('${caution}', _('ctt_confirmation_wizard_page_view_caution_html'));
  } else {
    cfg.title = _('ctt_transfer_wizard_title');
    cfg.bodyContent = TEMPLATE.
                      replace('${dms}', _('ctt_confirmation_wizard_page_view_information_label_dms')).
                      replace('${storage}', _('ctt_confirmation_wizard_page_view_information_label_storage')).
                      replace('${scheduled}', _('ctt_confirmation_wizard_page_view_information_label_scheduled')).
                      replace('${shutdownOnceFinished}',  _('ctt_confirmation_wizard_page_view_shutdown_once_finished')).
                      replace('${caution}', _('ctt_confirmation_wizard_page_view_caution_html'));
  }

  cfg = dixim.extend(cfg, configs);
  buttons = [
    {
      id: 'next',
      text: _('ctt_transfer_wizard_button_label_transfer'),
      click: $.proxy(this._didClickTransfer, this)
    },
    {
      text: _('ctt_transfer_wizard_button_label_back'),
      click: $.proxy(this._didClickBack, this)
    },
    {
      text: _('ctt_transfer_wizard_button_label_cancel'),
      click: $.proxy(this._didClickCancel, this),
      align: 'left'
    }
  ];

  cfg.buttons = buttons;
  superConstructor.prototype._initialize.call(this, cfg);
};

prototype._didRenderDialog = function(e) {
  var form;

  form = $('.ctt-confirmation-wizard-page-view-shutdown', this._view);
  form.bind('click', {form: form}, $.proxy(this._didClickForm, this));

  superConstructor.prototype._didRenderDialog.call(this, e);
};

prototype._didClickForm = function(e) {
  var f = e.data.form;
  var check;
  var cls = 'ctt-confirmation-wizard-page-view-shutdown-selected';

  check = $('input[name="shutdown"]', f);
  if (check.hasClass(cls)) {
    check.removeClass(cls).
          attr('checked', false);
  } else {
    check.addClass(cls).
          attr('checked', true);
  }
};

prototype._didClickTransfer = function(e) {
  this.dispatchEvent(new Event('transfer'));
};

prototype._didClickBack = function(e) {
  this.dispatchEvent(new Event('back'));
};

prototype._didClickCancel = function(e) {
  this.dispatchEvent(new Event('cancel'));
};

prototype.setNumberOfItems = function(num) {
  var s;

  if (this._isDownloadMoveIn) {
    s = _('ctt_confirmation_wizard_page_view_description_download', num);
  } else {
    s = _('ctt_confirmation_wizard_page_view_description', num);
  }
  $('.ctt-confirmation-wizard-page-view-description', this._view).text(s);
};

prototype.setMoveItemView = function() {
  $('.ctt-confirmation-wizard-page-view-collected-information').remove();
  $('.ctt-confirmation-wizard-page-view-description', this._view).html(_('ctt_confirmation_wizard_move_item_description'));
  $('div#ctt-confirmation-wizard-caution').
    html(_('ctt_confirmation_wizard_move_item_caution')).
    prop('class', 'ctt-confirmation-wizard-page-view-caution');
  $('div#ctt-confirmation-wizard-confirm').
    html(_('ctt_confirmation_wizard_move_item_confirm')).
    prop('class', 'ctt-confirmation-wizard-page-view-confirm');
  $('button#next').html(_('ctt_transfer_wizard_button_label_yes'));
};

prototype.setMoveOneItemView = function() {
  $('.ctt-confirmation-wizard-page-view-collected-information').remove();
  $('.ctt-confirmation-wizard-page-view-description', this._view).html(_('ctt_confirmation_wizard_move_one_item_description'));
  $('div#ctt-confirmation-wizard-caution').remove();
  $('div#ctt-confirmation-wizard-confirm').
    html(_('ctt_confirmation_wizard_move_item_confirm')).
    prop('class', 'ctt-confirmation-wizard-page-view-confirm');
  $('button#next').html(_('ctt_transfer_wizard_button_label_yes'));
};

prototype.setMoveSameItemView = function(count) {
  $('.ctt-confirmation-wizard-page-view-collected-information').remove();
  $('.ctt-confirmation-wizard-page-view-description', this._view).html(_('ctt_confirmation_wizard_move_same_item_description', count));
  $('div#ctt-confirmation-wizard-caution').remove();
  $('div#ctt-confirmation-wizard-confirm').
    html(_('ctt_confirmation_wizard_move_item_confirm')).
    prop('class', 'ctt-confirmation-wizard-page-view-confirm');
  $('button#next').html(_('ctt_transfer_wizard_button_label_yes'));
};

prototype.setDmsName = function(name) {
  this._setInformationText('ctt-confirmation-wizard-page-view-collected-information-dms-name', name);
};

prototype.setStorageName = function(name) {
  this._setInformationText('ctt-confirmation-wizard-page-view-collected-information-storage-name', name);
};

prototype.setScheduledDate = function(date) {
  var d;
  var t;
  var val;

  if (!!date) {
    d = [date.getFullYear(), date.getMonth() + 1, date.getDate()].join('/');
    t = [date.getHours(), date.getMinutes()].join(':');
    val = [d, t].join(' ');
  } else {
    val = null;
  }
  this._setInformationText('ctt-confirmation-wizard-page-view-collected-information-scheduled-date', val);
};

prototype.setLcPowerOff = function(val) {
  var f;

  f = $('.ctt-confirmation-wizard-page-view-shutdown', this._view);
  if (!!val) {
    f.show();
  } else {
    f.hide();
  }
};

prototype.setDestLocalContainerName = function(storage, container) {
  var text;

  text = _('ctt_confirmation_wizard_page_view_information_label_storage_value_download', storage, container);
  this._setInformationText('ctt-confirmation-wizard-page-view-collected-information-storage-name', text);
};

prototype.isShutdownOnceFinishedSelected = function() {
  var f;

  f = $('.ctt-confirmation-wizard-page-view-shutdown', this._view);
  return !!$('input[name="shutdown"]', f).attr('checked');
};

prototype._setInformationText = function(className, text) {
  var node;

  node = $('.' + className, this._view);
  if (!!text) {
    node.text(text).parent().show();
  } else {
    node.parent().hide();
  }
};

}());
