/**
 * @module ctt
 * @submodule confirmation-wizard-page-controller
 */
(function() {
var Event = dixim.event.Event;
var WizardPageController = dixim.ctt.WizardPageController;
var ConfirmationWizardPageView = dixim.ctt.ConfirmationWizardPageView;
var TransactionWizardPageController = dixim.ctt.TransactionWizardPageController;

var ConfirmationWizardPageController;
var prototype;
var superConstructor;

/**
 * @class ConfirmationWizardPageController
 * @extends WizardPageController
 * @constructor
 * @param {Object} configs
 */
ConfirmationWizardPageController = function(configs) {
  WizardPageController.call(this, configs);
};
dixim.inherit(ConfirmationWizardPageController, WizardPageController);
dixim.ctt.ConfirmationWizardPageController = ConfirmationWizardPageController;
prototype = ConfirmationWizardPageController.prototype;
superConstructor = ConfirmationWizardPageController.superConstructor;

prototype._createView = function() {
  this._isDownloadMoveIn = this._wizard.getRegistryEntry('isDownloadMoveIn');
  this._view = new ConfirmationWizardPageView({
    isDownloadMoveIn: this._isDownloadMoveIn
  });
};

prototype.start = function() {
  var v;

  if (!!!this._view) {
    this._createView();
  }

  v = this._view;
  v.addEventListener('render', this._didRenderView, this);
  v.addEventListener('cancel', this._didCancel, this);
  v.addEventListener('transfer', this._didClickTransfer, this);
  v.addEventListener('back', this._didClickBack, this);

  superConstructor.prototype.start.call(this);
};

prototype._didRenderView = function(e) {
  var v = this._view;
  var wizard;
  var dms;
  var device;
  var storage;
  var container;
  var items;
  var scheduledDate = null;

  if (!!!(wizard = this._wizard)) {
    throw new Error('not pushed into wizard stack');
  }

  items = wizard.getRegistryEntry('targetItems');

  if (!!wizard.getRegistryEntry('scheduled')) {
    scheduledDate = wizard.getRegistryEntry('scheduledDate');
    v.setScheduledDate(scheduledDate);
  } else {
    v.setScheduledDate(null);
  }

  v.setNumberOfItems(items.length);
  if (this._isDownloadMoveIn) {
    device = wizard.getRegistryEntry('sourceDevice');
    storage = wizard.getRegistryEntry('destLocalStorage');
    v.setDmsName(device.name);
    v.setLcPowerOff(!!device.lcPoweroff);
  } else {
    dms = wizard.getRegistryEntry('dms');
    storage = wizard.getRegistryEntry('destStorage');
    v.setDmsName(dms.friendlyName);
    v.setLcPowerOff(!!dms.lcPoweroff);
  }

  if (this._isDownloadMoveIn) {
    container = wizard.getRegistryEntry('destLocalContainer');
    v.setDestLocalContainerName(storage.name, container.title);
  } else {
    if (!!storage) {
      v.setStorageName(storage.friendlyName);
    } else {
      v.setStorageName(null);
    }
  }
};

prototype._didClickTransfer = function(e) {
  var v = this._view;
  var w = this._wizard;
  var vc;

  w.setRegistryEntry('shutdownOnceFinished',
                     v.isShutdownOnceFinishedSelected());

  vc = new TransactionWizardPageController();
  w.pushViewController(vc);
};

prototype._didClickBack = function(e) {
  var vc;
  var w = this._wizard;

  if (!!w) {
    vc = w.popViewController();
    vc.destroy();
  }
};
}());
