/**
 * @module ctt
 * @submodule schedule-entry-listing-controller
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var ScheduleEntryListingView = dixim.ctt.ScheduleEntryListingView;

var ScheduleEntryListingController;
var prototype;

/**
 * @class ScheduleEntryListingController
 * @constructor
 * @param {Object} configs
 */
ScheduleEntryListingController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(ScheduleEntryListingController, EventTarget);
dixim.ctt.ScheduleEntryListingController = ScheduleEntryListingController;
prototype = ScheduleEntryListingController.prototype;

/**
 * @event changeSelection
 */
var CHANGE_SELECTION = 'changeSelection';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 * @param {String|jQuery} configs.containerNode
 * @param {boolean} [configs.selection=true]
 * @param {Object[]} [configs.entries]
 */
prototype._initialize = function(configs) {
  this._containerNode = configs.containerNode;
  this._selection = typeof configs.selection === 'undefined' ? true : configs.selection;
  this._records = configs.entries || [];
  this._view = new ScheduleEntryListingView({
    containerNode: this._containerNode,
    enableSelection: this._selection
  });
};

/**
 * @method start
 */
prototype.start = function() {
  var v = this._view;

  if (this._selection) {
    v.addEventListener('clickItem', this._didClickItem, this);
    v.addEventListener('changeSelection', this._didChangeSelection, this);
  }
  v.show();

  this._update();
};

prototype._didClickItem = function(e) {
  var record = e.args.record;

  this._view.toggleRowSelection(record);
};

prototype._didChangeSelection = function(e) {
  this.dispatchEvent(new Event(CHANGE_SELECTION));
};

/**
 * @method stop
 */
prototype.stop = function() {
  this._view.hide();
  
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  this._view.destroy();
};

/**
 * @method update
 * @param {Object[]} records
 */
prototype.update = function(records) {
  this._records = records;
  this._update();
};

prototype._update = function() {
  this._view.removeAllRows();
  this._view.addRows(this._records);
};

/**
 * @method getSelectedRows
 */
prototype.getSelectedEntries = function() {
  return this._view.getSelectedRows();
};

}());
