/**
 * @module ctt
 * @submodule wizard-page-controller
 */
(function() {
var Event = dixim.event.Event;
var EventTarget = dixim.event.EventTarget;
var WizardPageView = dixim.ctt.WizardPageView;

var WizardPageController;
var prototype;

/**
 * Abstract class provides methods to control a page(step) of the wizard.
 *
 * @class WizardPageController
 * @extends EventTarget
 * @constructor
 * @param {Object} configs
 */
WizardPageController = function(configs) {
  EventTarget.call(this);
  this._initialize(configs);
};
dixim.inherit(WizardPageController, EventTarget);
dixim.ctt.WizardPageController = WizardPageController;
prototype = WizardPageController.prototype;

/**
 * @event done
 */
var DONE = 'done';

/**
 * Triggered when the user cancelled the wizard.
 *
 * @event cancel
 */
var CANCEL = 'cancel';

/**
 * @method _initialize
 * @protected
 * @param {Object} configs
 */
prototype._initialize = function(configs) {
  this._view = null;
  this._wizard = null;
};

prototype._initializeDefaultView = function() {
  var v;

  v = new WizardPageView();
  v.addEventListener(CANCEL, this._didCancel, this);
  v.addEventListener(DONE, this._done, this);
  this._view = v;
};

/**
 * @method start
 */
prototype.start = function() {
  if (!!!this._view) {
    this._initializeDefaultView();
  }
  this._view.show();
};

prototype._didCancel = function(e) {
  this.dispatchEvent(new Event(CANCEL));
};

prototype._done = function(e) {
  this.dispatchEvent(new Event(DONE, {}));
};

/**
 * @method stop
 */
prototype.stop = function() {
  if (!!!this._view) return;
  this._view.hide();
};

/**
 * @method destroy
 */
prototype.destroy = function() {
  if (!!!this._view) return;
  this._view.destroy();
};

/**
 * @method setWizard
 * @param {TransferWizardController} wizard
 */
prototype.setWizard = function(wizard) {
  this._wizard = wizard;
};

}());
