#!/usr/bin/env python
# -*- mode: landisk-python; coding: utf-8; -*-
# vim:ts=4 sw=4 sts=4 ai si et sta

"""Do something for uninstalling the diximdms package."""

import os

import ionas.request as request
from product_conf import (LIBEXEC_DIR, STOR_IF_TO_VOL, )
from fal_info import (FAL_SERVICECTRL_PATH, Results, ReqTypes)

from pkgaddon.diximdms_config import (DMS_SERVICE,)

import manualctrl


HANDLER_FOR_SERVICE = os.path.join(LIBEXEC_DIR, "evh",
                                    "evh_diximdms_service.py")
INTERNAL_VOL = STOR_IF_TO_VOL["internal"][1]

UNMOUNT_EVENT_XML = '<events><eventinfo category="volume" ' + \
                                'action="unmount" previous="true">' + \
                    '<volume><name>' + INTERNAL_VOL + '</name></volume>' + \
                    '</eventinfo></events>'

SERVICELIST_NAME = "servicelist"
SERVICE_NAME = "service"
NAME_NAME = "name"


def __send_request(target, type, body=""):
    """Send request entry to "target"."""

    entry = request.Entry(type, body)
    return request.Request(target).request(entry).get_entry()


def stop_diximdms_service():
    """Stop service for the diximdms by a event handler."""

    __send_request(HANDLER_FOR_SERVICE, ReqTypes.EVENT, UNMOUNT_EVENT_XML)


def delete_diximdms_service():
    """Delete service for the diximdms package from a servicectrl's
       configuration file.
    """

    try:
        servicectrl_config = \
                    __send_request(FAL_SERVICECTRL_PATH, ReqTypes.LOAD).get()

        servicelist = servicectrl_config.get_node(SERVICELIST_NAME)
        for (idx, service) in \
                enumerate(servicelist.get_node_list(SERVICE_NAME)):

            try:
                if service.get_node(NAME_NAME).get_text() == DMS_SERVICE:
                    servicelist.delete_child(SERVICE_NAME, index=idx)
                    __send_request(FAL_SERVICECTRL_PATH, ReqTypes.SAVE,
                                    servicectrl_config)
                    return
            except:
                pass
    except:
        pass


#
# Main
#

manualctrl.uninstall()
stop_diximdms_service()
delete_diximdms_service()
